#! /usr/bin/env node

// 0. Get command line arguments
const cmdArgs = require('minimist')(process.argv.slice(2));

// 1. Validate the User's execution environment
// Exit with error if there is no aws configuration at the script's executing location
const path = require('path');
const awsConfigPath = path.join(process.cwd(), '.aws.json');
const fs = require('fs');
const { buildConfigFile } = require('./init');

// 2. Check to see if we need to init
if (cmdArgs._.includes('init')) {
  buildConfigFile();
  process.exit(0);
}

// 3. Make sure the config file exists
if (!fs.existsSync(awsConfigPath)) {
  console.error("No './.aws.json' config file in this folder. This configuration is needed to connect to your s3 bucket.");
  console.error("To set up this folder, use `push-text init`");
  console.error('');
  process.exit(405);
}
console.info(`Using configuration from '${awsConfigPath}'`);

// 3. Configure our AWS S3 instance
const AWS = require('aws-sdk');
AWS.config.loadFromPath(awsConfigPath);

// 4. Export the bootstraped configuration
const awsConfigFile = JSON.parse(fs.readFileSync(awsConfigPath).toString());
delete awsConfigFile.secretAccessKey; // rm credentials from the file so we can use that to extend config
const { Bucket } = awsConfigFile;
module.exports = Object.assign({
    s3: new AWS.S3({ params: { Bucket } }),
    inSyncFileDisplayThreshold: 5,
    maxSizeKb: 1000, // 1mb. Most people aren't typing plain text notes larger than this, I think. My largest hand-written files are about 250 kb.
    readDir: '.',
    outputDir: '.',
    ContentType: 'text/html',
    ServerSideEncryption: "AES256",
    exclude: [ 'node_modules', 'README.md' ],
    includeExtensions: [ 'txt', 'text', 'md', 'markdown' ],
}, awsConfigFile, cmdArgs);
