const cmd = require('./cmd');
const fs = require('fs');

const commitMsg = "committed by 'push-text' script";
const author = "push-text script <push-text-bot@simple.gy>";
const skipIfSame = "git diff-index --quiet HEAD || "; // https://stackoverflow.com/questions/8123674/how-to-git-commit-nothing-without-an-error

// Set up a git repo, if one does not exist
// Might be useful:
// git rev-parse --show-toplevel === process.cwd()
// git rev-parse --git-dir
function init() {
  createGitignore(); // Very important, don't commit the AWS credentials in `.aws.json`
  return cmd("git --version")
    .then(cmd.bind(null, "git init"))
}

// Commit all files. Do nothing if there are no files to commit
function commitEverything() {
  return cmd(`git add -A`)
    .then(cmd.bind(null, `${skipIfSame} git commit -a --author="${author}" -m "${commitMsg}"`))
    .then(didCommit)
}

function didCommit(msg) {
  console.log('didCommit()');
  console.log();
  console.log(msg);
}

function createGitignore() {
  const credentials = '.aws.json';
  const file = './.gitignore';
  if (!fs.existsSync(file)) {
    console.log(`Adding a gitignore file and excluding the aws credentials at '${credentials}'`);
    fs.writeFileSync(file, `${credentials}\n`, 'utf8');
  }
}

module.exports = {
  save: () => init().then(commitEverything),
  createGitignore
};
