const leftPad = require('left-pad');
const { s3, verbose, inSyncFileDisplayThreshold } = require('../src/configure');
const { groupBy } = require('../src/utils');
const { localStateOf } = require('../src/localFiles');

// Compare local files to the remote
// Group by missing/inSync/different
// Log States
// When done, trigger the provided callback and give it the grouped files
function compareLocalToRemote(fn) {
    s3.listObjects({}, (err, data) => {
        if (err) {
            return console.warn(err);
        }
        const remoteFiles = data.Contents;
        const {missing = [], inSync = [], different = []} = groupBy(remoteFiles, localStateOf);

        // Output file counts
        console.log('');
        console.log(`${leftPad(missing.length, 5)} files on the remote do *not* exist locally. ${missing.length > 5 ? '(You may wish to `pull-text`)' : ''}`);
        console.log(`${leftPad(inSync.length, 5)} files in sync with the remote.`);
        console.log(`${leftPad(different.length, 5)} files have different local contents.`);
        console.log('');

        // Output individual file names
        if (inSync.length < inSyncFileDisplayThreshold || verbose) {
            inSync.forEach( f => console.log(`In sync:   '${f.Key}'`));
            console.log('');
        }

        // Holla back
        fn({ missing, inSync, different});
    });
}

module.exports = {
    compareLocalToRemote,
};
