const { s3, ServerSideEncryption, ContentType } = require('../src/configure');

// Given a list of s3 List objects, fetch them all from s3
// Call the provided function against each gotten file object on success
function getTheseFromS3(s3ListObjects, fn) {
    if (s3ListObjects.length === 0) return console.info("No need to fetch any files.");

    console.log('');
    console.log(`Downloading these ${s3ListObjects.length} files:`);
    s3ListObjects.forEach(o => console.log(o.Key));

    s3ListObjects.forEach(o => {
        const Key = o.Key;
        s3.getObject({
            Key
            // IfModifiedSince (date)
            // IfMatch (etag)
        }, (err, data) => {
            if (err) { return console.warn(err); }
            fn(Object.assign({ Key }, data)) // include at least the filename (o.Key) in the return data, you silly willies.
        });
    });
}

// Given a filename (Key) and body contents
// Upload the file to s3
function uploadFile({Key, Body}) {
    s3.putObject({
        Key,
        Body,
        ServerSideEncryption,
        ContentType
    }, (err, data) => {
        if (err) { return console.warn(err); }
        console.log(`Successfully uploaded: '${Key}' -- ${data.ETag}`);
    });
}

module.exports = {
    getTheseFromS3,
    uploadFile,
};
