
// Get the extension of a filename (for .multi.ext, returns the last)
const getExtension = name => name.split('.').pop();

// If there's a leading './', remove it
function removeRelativePath(path) {
    if (path.slice(0, 2) === './') {
        return path.slice(2);
    }
    return path;
}

// Given an array and a function,
// group the elements of the array by the output of the function
// like lodash's _.groupBy
function groupBy(arr = [], fn) {
    const grouped = {};
    arr.forEach( el => {
        const key = fn(el);
        grouped[key] = grouped[key] || [];
        grouped[key].push(el);
    });
    return grouped;
}

// Given a string,
// return a function that will pluck that property out of a given object
// useful for mapping, as in users.map(pluck('name'))
// Like lodash's pluck, iirc
const pluck = key =>
    (obj = {}) =>
        obj[key];

module.exports = {
    getExtension,
    removeRelativePath,
    groupBy,
    pluck,
};
